@@ -34,8 +34,6 @@ from soda.sodacl.dbt_check_cfg import DbtCheckCfg
 
 
 class DbtCloud:
-    ADMIN_API_BASE_URL = "https://cloud.getdbt.com/api/v2/accounts/"
-
     def __init__(
         self,
         scan: Scan,
@@ -112,20 +110,15 @@ class DbtCloud:
 
         return return_code
 
-    def flush_test_results(
-        self, check_results_iterator: Iterator[tuple[Dataset, list[Check]]], soda_cloud: SodaCloud
-    ) -> None:
-        for dataset, checks in check_results_iterator:
-            if len(checks) == 0:
-                continue
+    def flush_test_results(self, checks: list[Check], soda_cloud: SodaCloud) -> None:
+
+        if len(checks) != 0:
             scan_results = self.build_scan_results(checks)
             scan_results["type"] = "sodaCoreInsertScanResults"
-
-            return soda_cloud._execute_command(scan_results, command_name="send_scan_results")
+            soda_cloud._execute_command(scan_results, command_name="send_scan_results")
 
     def build_scan_results(self, checks):
         check_dicts = [check.get_cloud_dict() for check in checks]
-
         return JsonHelper.to_jsonnable(  # type: ignore
             {
                 "definitionName": self.scan._scan_definition_name,
@@ -179,6 +172,7 @@ class DbtCloud:
         )
 
         soda_checks = self._dbt_run_results_to_soda_checks(test_nodes, parsed_run_results)
+        checks = []
         for unique_id, test_unique_ids in models_with_tests.items():
             node = model_seed_and_source_nodes[unique_id]
             dataset = Dataset(
@@ -186,14 +180,14 @@ class DbtCloud:
                 node.database,
                 node.schema,
             )
-            checks = []
 
             for test_unique_id in test_unique_ids:
                 check: DbtCheck = soda_checks[test_unique_id]
                 check.dataset = dataset
+                check.check_cfg.table_name = dataset.name
                 checks.append(check)
 
-            yield dataset, checks
+        return checks
 
     def _dbt_run_results_to_soda_checks(
         self,
@@ -212,16 +206,16 @@ class DbtCloud:
         for run_result in run_results:
             if run_result.unique_id in test_nodes.keys():
                 test_node = test_nodes[run_result.unique_id]
+                self.scan._logs.debug(f"Ingesting test node '{test_node.name}' (id: '{test_node.unique_id}').")
+
                 check = DbtCheck(
                     check_cfg=DbtCheckCfg(
                         name=test_node.name,
                         file_path=test_node.original_file_path,
-                        # TODO Hacky way to get the model name, currently it picks the first ref
-                        table_name=test_node.refs[0][0],
                         column_name=test_node.column_name,
                     ),
                     identity=test_node.unique_id,
-                    expression=test_node.compiled_sql,
+                    expression=test_node.compiled_sql if hasattr(test_node, "compiled_sql") else None,
                 )
                 check.data_source_scan = self.scan._get_or_create_data_source_scan(self.scan._data_source_name)
                 if run_result.status == TestStatus.Pass:
@@ -234,7 +228,6 @@ class DbtCloud:
                 # values={"failures": run_result.failures}, - take this into diagnostics?
 
                 checks[run_result.unique_id] = check
-
         return checks
 
     def _download_dbt_artifact_from_cloud(
@@ -265,13 +258,13 @@ class DbtCloud:
                 "Either a dbt run_id or a job_id must be provided. If a job_id is provided "
                 "soda ingest will fetch the latest available run artifacts from dbt Cloud for that job_id."
             )
-        url = f"{self.ADMIN_API_BASE_URL}{account_id}/runs/{run_id}/artifacts/{artifact}"
+        url = f"{self.dbt_cloud_config.api_url}{account_id}/runs/{run_id}/artifacts/{artifact}"
 
         headers = CaseInsensitiveDict()
         headers["Authorization"] = f"Token {api_token}"
         headers["Content-Type"] = "application/json"
 
-        self.scan_logs.info(f"Downloading artifact: {artifact}, from run: {run_id}")
+        self.scan._logs.info(f"Downloading artifact: {artifact}, from run: {run_id}")
 
         response = requests.get(url, headers=headers)
         if response.status_code != requests.codes.ok:
@@ -280,7 +273,7 @@ class DbtCloud:
         return response.json()
 
     def _get_latest_run_id(self, api_token: str, account_id: str, job_id: str) -> str | None:
-        url = f"{self.ADMIN_API_BASE_URL}{account_id}/runs"
+        url = f"{self.dbt_cloud_config.api_url}{account_id}/runs"
 
         headers = CaseInsensitiveDict()
         headers["Authorization"] = f"Token {api_token}"
